@@ -5,48 +5,50 @@ from zigzag.classes.io.onnx.utils import get_node_input_output_dimension_shapes
 from zigzag.classes.workload.layer_node import LayerNode
 
 import logging
+
 logger = logging.getLogger(__name__)
 
-
+## Parses an ONNX MatMul operator into a LayerNode
 class MatMulParser(Parser):
-    """Parses an ONNX MatMul operator into a LayerNode
-    """
+
+    ## The class constructor
+    # @param node_id
+    # @param node
+    # @param nodes_outputs
+    # @param mapping
+    # @param onnx_model
     def __init__(self, node_id, node, nodes_outputs, mapping, onnx_model) -> None:
         super().__init__(node_id, node, nodes_outputs, mapping, onnx_model)
-    
+
+    ## Run the parser
     def run(self):
-        """Run the parser
-        """
         layer_node = self.generate_layer_node_for_matmul()
         return layer_node
 
     def generate_layer_node_for_matmul(self):
-    
+        ## Generate the necessary dictionary items required for the Node creation.
         def get_layer_node_input_format(B, C, K, node_mapping, nodes_outputs):
-            """
-            Generate the necessary dictionary items required for the Node creation.
-            """
-            # convert the data types to precisions based on the onnx definition
 
+            # convert the data types to precisions based on the onnx definition
 
             # Equation
             d = {}
-            d["equation"] = 'O[b][k]+=B[k][c]*A[b][c]'
+            d["equation"] = "O[b][k]+=B[k][c]*A[b][c]"
 
             # Get dimension sizes from input parameters
             K = K
             C = C
             B = B  # Not to be confused with operand 'B' which is the weights
-            d["loop_dim_size"] = {'K': K, 'C': C, 'B': B}
+            d["loop_dim_size"] = {"K": K, "C": C, "B": B}
             d["dimension_relations"] = []
-            d["operand_precision"] =  {'O': 16, 'O_final': 8, 'B': 8, 'A': 8}
-            d["operand_source"] =  {'B': [], 'A': []}
-            d["constant_operands"] =  ['B']
+            d["operand_precision"] = {"O": 16, "O_final": 8, "B": 8, "A": 8}
+            d["operand_source"] = {"B": [], "A": []}
+            d["constant_operands"] = ["B"]
 
-            d["core_allocation"] =  node_mapping["core_allocation"]
-            d["spatial_mapping"] =  node_mapping["spatial_mapping"]
+            d["core_allocation"] = node_mapping["core_allocation"]
+            d["spatial_mapping"] = node_mapping["spatial_mapping"]
             d["temporal_ordering"] = node_mapping.get("temporal_ordering", None)
-            d["memory_operand_links"] =  {'O': 'O', 'B': 'I2', 'A': 'I1'}
+            d["memory_operand_links"] = {"O": "O", "B": "I2", "A": "I1"}
 
             # Find the previous layer(s) that should be this node's parent(s)
             node_inputs = self.node.input
@@ -55,14 +57,20 @@ class MatMulParser(Parser):
                 for n in nodes_outputs:
                     if node_input in nodes_outputs[n]:
                         preds.append(n)
-            d["operand_source"] = {'A': preds}
+            d["operand_source"] = {"A": preds}
 
             return d
-        
-        ia_dimension_shape, oa_dimension_shape = get_node_input_output_dimension_shapes(self.node, self.onnx_model)
 
-        assert len(ia_dimension_shape) == len(oa_dimension_shape) == 2  # First element is batch size, second is input/output channel
-        assert ia_dimension_shape[0] == oa_dimension_shape[0]  # Batch size should be the same for input and output
+        ia_dimension_shape, oa_dimension_shape = get_node_input_output_dimension_shapes(
+            self.node, self.onnx_model
+        )
+
+        assert (
+            len(ia_dimension_shape) == len(oa_dimension_shape) == 2
+        )  # First element is batch size, second is input/output channel
+        assert (
+            ia_dimension_shape[0] == oa_dimension_shape[0]
+        )  # Batch size should be the same for input and output
         # If the batch size is 0, we discard it by setting it to 1 internally inside ZigZag
         batch_size = ia_dimension_shape[0]
         if batch_size == 0:
@@ -72,17 +80,26 @@ class MatMulParser(Parser):
         C = ia_dimension_shape[1]
         K = oa_dimension_shape[1]
 
-        # Get the hw mapping of this node. 
+        # Get the hw mapping of this node.
         if self.node.name in self.mapping:
             node_mapping = self.mapping[self.node.name]
         else:
             try:
                 node_mapping = self.mapping["default"]
             except:
-                raise ValueError(f"There is no mapping provided for node {self.node.name}, nor a default one.")
+                raise ValueError(
+                    f"There is no mapping provided for node {self.node.name}, nor a default one."
+                )
 
-        node_attrs = get_layer_node_input_format(B, C, K, node_mapping, self.nodes_outputs)
-        node_obj = LayerNode(self.node_id, node_attrs, node_name=self.node.name, type=self.node.op_type.lower())
+        node_attrs = get_layer_node_input_format(
+            B, C, K, node_mapping, self.nodes_outputs
+        )
+        node_obj = LayerNode(
+            self.node_id,
+            node_attrs,
+            node_name=self.node.name,
+            type=self.node.op_type.lower(),
+        )
 
         logger.info(f"Parsed MatMul node {self.node.name}")
 
