@@ -1,20 +1,13 @@
 from abc import ABCMeta
 
-
+## Abstract base class that represents a loop. Could be spatial or temporal loop.
 class Loop(metaclass=ABCMeta):
-    """Abstract base class that represents a loop.
-    Could be spatial or temporal loop.
-    """
+
+    ## The class constructor
+    # Initialize this Loop object.
+    # @param dimension (str): The dimension, e.g. "K"
+    # @param size (float): The loop size, e.g. 16.0
     def __init__(self, dimension, size) -> None:
-        """Initialize this Loop object.
-
-        Args:
-            dimension (str): The dimension, e.g. "K"
-            size (float): The loop size, e.g. 16.0 
-
-        Returns:
-            None: None
-        """
         self.type = None
         self.dimension = dimension
         self.size = size
@@ -23,4 +16,4 @@ class Loop(metaclass=ABCMeta):
     #     return f"Loop({self.dimension},{self.size})"
 
     # def __repr__(self):
-    #     return str(self)
\ No newline at end of file
+    #     return str(self)
