@@ -1,9 +1,11 @@
 from zigzag.classes.mapping.loop import Loop
 
-
+## Class that represents a temporal loop.
 class TemporalLoop(Loop):
-    """Class that represents a temporal loop.
-    """
+
+    ## The class constructor
+    # @param dimension
+    # @param size
     def __init__(self, dimension, size) -> None:
         super().__init__(dimension, size)
         self.type = "temporal"
@@ -12,4 +14,4 @@ class TemporalLoop(Loop):
         return f"TemporalLoop({self.dimension},{self.size})"
 
     def __repr__(self):
-        return str(self)
\ No newline at end of file
+        return str(self)
