@@ -4,6 +4,7 @@ import matplotlib.pyplot as plt
 
 from zigzag.classes.hardware.architecture.memory_hierarchy import MemoryHierarchy
 
+
 def visualize_memory_hierarchy_graph(G: MemoryHierarchy):
     """
     Visualizes a memory hierarchy graph.
@@ -26,16 +27,26 @@ def visualize_memory_hierarchy_graph(G: MemoryHierarchy):
             pos[node] = (x, y)
             node_list.append(node)
             node_size_list.append(node_size)
-            node_label_dict[node] = f"{node.name}\n{node.operands}\nx{node.unroll_count}"
+            node_label_dict[
+                node
+            ] = f"{node.name}\n{node.operands}\nx{node.unroll_count}"
 
-    nx.draw(G, pos=pos, node_shape='s', nodelist=node_list, node_size=node_size_list, labels=node_label_dict)
+    nx.draw(
+        G,
+        pos=pos,
+        node_shape="s",
+        nodelist=node_list,
+        node_size=node_size_list,
+        labels=node_label_dict,
+    )
     plt.title(G.name)
     plt.show()
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     import pickle
-    with open('../list_of_cmes.pickle', 'rb') as handle:
+
+    with open("../list_of_cmes.pickle", "rb") as handle:
         list_of_cme = pickle.load(handle)
     cme = list_of_cme[0]
-    visualize_memory_hierarchy_graph(cme.accelerator.cores[0].memory_hierarchy)
\ No newline at end of file
+    visualize_memory_hierarchy_graph(cme.accelerator.cores[0].memory_hierarchy)
